"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require("react");
var _ = require("underscore");
var formBinders_1 = require("../../form/formBinders");
var dateHelpers_1 = require('./../../../utilities/dateHelpers');
var grid_1 = require("./../../layout/grid");
var TimeInput = (function (_super) {
    __extends(TimeInput, _super);
    function TimeInput() {
        _super.call(this);
        this.state = { hours: null, minutes: null };
    }
    TimeInput.prototype.componentWillMount = function () {
        if (this.props.time) {
            var time = dateHelpers_1.DateHelpers.getTimeParts(this.props.time);
            this.setState({ hours: time.hours, minutes: time.minutes });
        }
    };
    TimeInput.prototype.hourChanged = function (hour) {
        var _this = this;
        var hours = parseInt(hour);
        this.setState({ hours: hours }, function () {
            _this.updateTime();
        });
    };
    TimeInput.prototype.minuteChanged = function (minute) {
        var _this = this;
        var minutes = parseInt(minute);
        this.setState({ minutes: minutes }, function () {
            _this.updateTime();
        });
    };
    TimeInput.prototype.updateTime = function () {
        if (this.props.onChange) {
            this.props.onChange(this.state.hours + ":" + this.state.minutes);
        }
    };
    TimeInput.prototype.componentWillReceiveProps = function (newProps) {
        if (newProps.time) {
            var newTime = dateHelpers_1.DateHelpers.getTimeParts(newProps.time);
            var hours = this.state.hours;
            var minutes = this.state.minutes;
            var needsUpdate = void 0;
            if (newTime.hours !== hours) {
                hours = newTime.hours;
                needsUpdate = true;
            }
            if (newTime.minutes !== minutes) {
                minutes = newTime.minutes;
                needsUpdate = true;
            }
            if (needsUpdate) {
                this.setState({ hours: hours, minutes: minutes });
            }
        }
        else {
            this.setState({ hours: null, minutes: null });
        }
    };
    TimeInput.prototype.render = function () {
        var _this = this;
        var hours = _.range(0, 24, 1);
        var minutes = _.range(0, 60, 1);
        return React.createElement(grid_1.Grid, null, 
            React.createElement(grid_1.Row, null, 
                React.createElement(grid_1.Col, null, 
                    React.createElement("select", {disabled: this.props.disabled, onChange: function (e) { return _this.hourChanged(e.target.value); }, value: this.state.hours ? this.state.hours.toString() : ""}, 
                        React.createElement("option", {disabled: true, value: ""}, "HH"), 
                        hours.map(function (d) { return React.createElement("option", {key: d.toString(), value: d.toString()}, d < 10 ? "0" + d : d); }))
                ), 
                React.createElement(grid_1.Col, null, 
                    React.createElement("select", {disabled: this.props.disabled, onChange: function (e) { return _this.minuteChanged(e.target.value); }, value: this.state.minutes ? this.state.minutes.toString() : ""}, 
                        React.createElement("option", {disabled: true, value: ""}, "MM"), 
                        minutes.map(function (d) { return React.createElement("option", {key: d.toString(), value: d.toString()}, d < 10 ? "0" + d : d); }))
                ))
        );
    };
    return TimeInput;
}(React.Component));
exports.TimeInput = TimeInput;
var TimeInputFormBinder = (function (_super) {
    __extends(TimeInputFormBinder, _super);
    function TimeInputFormBinder() {
        _super.apply(this, arguments);
    }
    TimeInputFormBinder.customValue = function (dataName) {
        return new TimeInputFormBinder(dataName, "time");
    };
    TimeInputFormBinder.prototype.handleValueChanged = function (props, dataBinder, notifyChanged) {
        var _this = this;
        props.onChange = function (e) {
            _this.onChanged(dataBinder, e, notifyChanged);
        };
    };
    return TimeInputFormBinder;
}(formBinders_1.FormBinderBase));
exports.TimeInputFormBinder = TimeInputFormBinder;
