"use strict";
var moment = require("moment");
var _ = require("underscore");
var DateHelpers = (function () {
    function DateHelpers() {
    }
    // Date helpers
    DateHelpers.getDaysArrayByMonth = function (date, month) {
        var activeMoment = date ? moment(date, "YYYY-MM-DD", true) : moment();
        if (month) {
            activeMoment.set("month", month - 1);
        }
        var daysInMonth = activeMoment.daysInMonth();
        return _.range(1, daysInMonth + 1).map(function (d) { return d.toString(); });
    };
    DateHelpers.getDateParts = function (date, includeDate) {
        if (includeDate === void 0) { includeDate = false; }
        var d = moment(date, "YYYY-MM-DD", true);
        var parts = { day: d.date(), month: d.month() + 1, year: d.year() };
        if (includeDate) {
            parts["date"] = date;
        }
        return parts;
    };
    DateHelpers.areSame = function (d1, d2) {
        return moment(d1).isSame(moment(d2));
    };
    DateHelpers.getMonthValues = function () {
        return _.range(0, 12).map(function (i) {
            var month = moment().month(i);
            return { value: month.format("M"), label: month.format("MMMM") };
        });
    };
    DateHelpers.isBefore = function (date1, date2, granularity) {
        var d1 = moment(date1, "YYYY-MM-DD", true);
        var d2 = moment(date2, "YYYY-MM-DD", true);
        return d1.isBefore(d2);
    };
    DateHelpers.isAfter = function (date1, date2, granularity) {
        var d1 = moment(date1, "YYYY-MM-DD", true);
        var d2 = moment(date2, "YYYY-MM-DD", true);
        return d1.isBefore(d2);
    };
    DateHelpers.isEndOfMonth = function (date) {
        var endOfMonth = moment(date).endOf('month');
        return endOfMonth.isSame(date, 'day');
    };
    DateHelpers.getYearValues = function (futureDates, yearsFromNow) {
        if (yearsFromNow === void 0) { yearsFromNow = 110; }
        return _.range(0, yearsFromNow).map(function (i) { return futureDates ? moment().add(i, 'years').year() : moment().subtract(i, 'years').year(); });
    };
    DateHelpers.toDateFormat = function (s) {
        if (s.day && s.month && s.year) {
            var m = moment().set("date", s.day).set("month", s.month - 1).set("year", s.year).format("YYYY-MM-DD");
            return m;
        }
    };
    // Time helpers
    DateHelpers.getTimeParts = function (time) {
        var d = moment(time, "HH:mm", false);
        return { hours: d.hour(), minutes: d.minute() };
    };
    return DateHelpers;
}());
exports.DateHelpers = DateHelpers;
